# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import analysis_config_pb2 as analysis__config__pb2


class AnalysisConfigApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.AnalysisConfigApi/create',
                request_serializer=analysis__config__pb2.AnalysisConfigCreateRequest.SerializeToString,
                response_deserializer=analysis__config__pb2.AnalysisConfigCreateResponse.FromString,
                )
        self.update = channel.unary_unary(
                '/oi.papi.AnalysisConfigApi/update',
                request_serializer=analysis__config__pb2.AnalysisConfigUpdateRequest.SerializeToString,
                response_deserializer=analysis__config__pb2.AnalysisConfigUpdateResponse.FromString,
                )
        self.get = channel.unary_unary(
                '/oi.papi.AnalysisConfigApi/get',
                request_serializer=analysis__config__pb2.AnalysisConfigGetRequest.SerializeToString,
                response_deserializer=analysis__config__pb2.AnalysisConfigGetResponse.FromString,
                )
        self.list = channel.unary_unary(
                '/oi.papi.AnalysisConfigApi/list',
                request_serializer=analysis__config__pb2.AnalysisConfigListRequest.SerializeToString,
                response_deserializer=analysis__config__pb2.AnalysisConfigListResponse.FromString,
                )
        self.deactivate = channel.unary_unary(
                '/oi.papi.AnalysisConfigApi/deactivate',
                request_serializer=analysis__config__pb2.AnalysisConfigDeactivateRequest.SerializeToString,
                response_deserializer=analysis__config__pb2.AnalysisConfigDeactivateResponse.FromString,
                )


class AnalysisConfigApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Creates a configuration of the specified AnalysisVersion, including concrete values for all of the Analysis parameters.
        This configuration is stored in the system and the analysis_config is returned to the user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        Updates name, description or algorithm_config_nodes in the specified AnalysisConfig.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Retrieve the metadata of a particular AnalysisConfig.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        Retrieve the metadata for all AnalysisConfigs that this user has access to and that match the provided search filters.
        By default, deactivated AnalysisConfigs are not returned. Setting include_deactivated to true will also return any AnalysisConfigs that had been deactivated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deactivate(self, request, context):
        """
        Deactivate the specific configuration of an AnalysisVersion.
        Deactivated AnalysisConfigs will no longer show up in searches, but metadata can still be retrieved for deactivated AnalysisConfigs via the get endpoint.
        Deactivated AnalysisConfigs cannot be used in any new AnalysisComputations, but existing AnalysisComputations will continue to function properly.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AnalysisConfigApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=analysis__config__pb2.AnalysisConfigCreateRequest.FromString,
                    response_serializer=analysis__config__pb2.AnalysisConfigCreateResponse.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=analysis__config__pb2.AnalysisConfigUpdateRequest.FromString,
                    response_serializer=analysis__config__pb2.AnalysisConfigUpdateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=analysis__config__pb2.AnalysisConfigGetRequest.FromString,
                    response_serializer=analysis__config__pb2.AnalysisConfigGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=analysis__config__pb2.AnalysisConfigListRequest.FromString,
                    response_serializer=analysis__config__pb2.AnalysisConfigListResponse.SerializeToString,
            ),
            'deactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.deactivate,
                    request_deserializer=analysis__config__pb2.AnalysisConfigDeactivateRequest.FromString,
                    response_serializer=analysis__config__pb2.AnalysisConfigDeactivateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AnalysisConfigApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AnalysisConfigApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AnalysisConfigApi/create',
            analysis__config__pb2.AnalysisConfigCreateRequest.SerializeToString,
            analysis__config__pb2.AnalysisConfigCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AnalysisConfigApi/update',
            analysis__config__pb2.AnalysisConfigUpdateRequest.SerializeToString,
            analysis__config__pb2.AnalysisConfigUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AnalysisConfigApi/get',
            analysis__config__pb2.AnalysisConfigGetRequest.SerializeToString,
            analysis__config__pb2.AnalysisConfigGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AnalysisConfigApi/list',
            analysis__config__pb2.AnalysisConfigListRequest.SerializeToString,
            analysis__config__pb2.AnalysisConfigListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AnalysisConfigApi/deactivate',
            analysis__config__pb2.AnalysisConfigDeactivateRequest.SerializeToString,
            analysis__config__pb2.AnalysisConfigDeactivateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import user_pb2 as user__pb2


class UserApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.login = channel.unary_unary(
                '/oi.papi.UserApi/login',
                request_serializer=user__pb2.LoginRequest.SerializeToString,
                response_deserializer=user__pb2.LoginResponse.FromString,
                )
        self.change_password = channel.unary_unary(
                '/oi.papi.UserApi/change_password',
                request_serializer=user__pb2.UserChangePasswordRequest.SerializeToString,
                response_deserializer=user__pb2.UserChangePasswordResponse.FromString,
                )
        self.create = channel.unary_unary(
                '/oi.papi.UserApi/create',
                request_serializer=user__pb2.UserCreateRequest.SerializeToString,
                response_deserializer=user__pb2.UserCreateResponse.FromString,
                )
        self.get = channel.unary_unary(
                '/oi.papi.UserApi/get',
                request_serializer=user__pb2.UserGetRequest.SerializeToString,
                response_deserializer=user__pb2.UserGetResponse.FromString,
                )
        self.list = channel.unary_unary(
                '/oi.papi.UserApi/list',
                request_serializer=user__pb2.UserListRequest.SerializeToString,
                response_deserializer=user__pb2.UserListResponse.FromString,
                )


class UserApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def login(self, request, context):
        """
        Login using user's email and password.
        The endpoint returns a JWT access token that is needed to use the API.
        Note: This endpoint does NOT require token authentication.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def change_password(self, request, context):
        """
        Change current User's password
        Note: This is an authenticated endpoint, but still requires old password to be sent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create(self, request, context):
        """
        Create a new User in the system, assigned to the specified department.
        This functionality is only available for an admin user.
        This automatically creates an AOICollection associated to this user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Returns the details of the specified User. If no User is given, returns details for the requesting User.
        The specified User must belong to the same UserCollection as the requesting User, otherwise an error is thrown.
        The user_id is a uuid and is actually the folder ID, so its a subject ID. Access limitations apply.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        List users. Access limitations apply.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'login': grpc.unary_unary_rpc_method_handler(
                    servicer.login,
                    request_deserializer=user__pb2.LoginRequest.FromString,
                    response_serializer=user__pb2.LoginResponse.SerializeToString,
            ),
            'change_password': grpc.unary_unary_rpc_method_handler(
                    servicer.change_password,
                    request_deserializer=user__pb2.UserChangePasswordRequest.FromString,
                    response_serializer=user__pb2.UserChangePasswordResponse.SerializeToString,
            ),
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=user__pb2.UserCreateRequest.FromString,
                    response_serializer=user__pb2.UserCreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=user__pb2.UserGetRequest.FromString,
                    response_serializer=user__pb2.UserGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=user__pb2.UserListRequest.FromString,
                    response_serializer=user__pb2.UserListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.UserApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.UserApi/login',
            user__pb2.LoginRequest.SerializeToString,
            user__pb2.LoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def change_password(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.UserApi/change_password',
            user__pb2.UserChangePasswordRequest.SerializeToString,
            user__pb2.UserChangePasswordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.UserApi/create',
            user__pb2.UserCreateRequest.SerializeToString,
            user__pb2.UserCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.UserApi/get',
            user__pb2.UserGetRequest.SerializeToString,
            user__pb2.UserGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.UserApi/list',
            user__pb2.UserListRequest.SerializeToString,
            user__pb2.UserListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: imagery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import aoi_pb2 as aoi__pb2
try:
  common__models__pb2 = aoi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.aoi_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rimagery.proto\x12\x0foi.papi.imagery\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\x1a\taoi.proto\"\xd8\x04\n\x14ImagerySearchRequest\x12(\n\x06\x61oi_id\x18\x01 \x01(\x0b\x32\x16.oi.papi.AOIIdentifierH\x00\x12\x16\n\x0cgeometry_wkb\x18\x02 \x01(\x0cH\x00\x12\x10\n\x06toi_id\x18\x03 \x01(\tH\x01\x12\x45\n\ntime_range\x18\x04 \x01(\x0b\x32/.oi.papi.imagery.ImagerySearchRequest.TimeRangeH\x01\x12\x16\n\x0e\x64\x61ta_source_id\x18\x05 \x01(\t\x12\x19\n\x11product_spec_name\x18\x06 \x01(\t\x12\x34\n\x13\x64\x61ta_source_filters\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\npagination\x18\t \x01(\x0b\x32\x13.oi.papi.Pagination\x12M\n\x0fsampling_config\x18\n \x01(\x0b\x32\x34.oi.papi.imagery.ImagerySearchRequest.SamplingConfig\x1a\x42\n\x0eSamplingConfig\x12\x17\n\x0f\x66requency_hours\x18\x01 \x01(\r\x12\x17\n\x0ftolerance_hours\x18\x02 \x01(\r\x1aj\n\tTimeRange\x12-\n\tstart_utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nfinish_utc\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\n\x04\x61reaB\x06\n\x04timeJ\x04\x08\x08\x10\t\"\xd5\x02\n\x15ImagerySearchResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12K\n\x07results\x18\x02 \x03(\x0b\x32:.oi.papi.imagery.ImagerySearchResponse.ImagerySearchResult\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\x1a\xb0\x01\n\x13ImagerySearchResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x19\n\x11provider_scene_id\x18\x02 \x01(\t\x12\x16\n\x0eimage_geom_wkb\x18\x03 \x01(\x0c\x12/\n\x0b\x61\x63quired_ts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct2e\n\nImageryApi\x12W\n\x06search\x12%.oi.papi.imagery.ImagerySearchRequest\x1a&.oi.papi.imagery.ImagerySearchResponseP\x02P\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'imagery_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_IMAGERYSEARCHREQUEST']._serialized_start=130
  _globals['_IMAGERYSEARCHREQUEST']._serialized_end=730
  _globals['_IMAGERYSEARCHREQUEST_SAMPLINGCONFIG']._serialized_start=534
  _globals['_IMAGERYSEARCHREQUEST_SAMPLINGCONFIG']._serialized_end=600
  _globals['_IMAGERYSEARCHREQUEST_TIMERANGE']._serialized_start=602
  _globals['_IMAGERYSEARCHREQUEST_TIMERANGE']._serialized_end=708
  _globals['_IMAGERYSEARCHRESPONSE']._serialized_start=733
  _globals['_IMAGERYSEARCHRESPONSE']._serialized_end=1074
  _globals['_IMAGERYSEARCHRESPONSE_IMAGERYSEARCHRESULT']._serialized_start=898
  _globals['_IMAGERYSEARCHRESPONSE_IMAGERYSEARCHRESULT']._serialized_end=1074
  _globals['_IMAGERYAPI']._serialized_start=1076
  _globals['_IMAGERYAPI']._serialized_end=1177
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aoi_version.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import aoi_pb2 as aoi__pb2
try:
  common__models__pb2 = aoi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.aoi_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61oi_version.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\taoi.proto\"s\n\x14\x41OIVersionGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\r\x12%\n\naoi_fields\x18\x02 \x03(\x0e\x32\x11.oi.papi.AOIField\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x80\x01\n\x15\x41OIVersionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12)\n\x0c\x61oi_versions\x18\x03 \x03(\x0b\x32\x13.oi.papi.AOIVersion\"\\\n\x17\x41OIVersionCreateRequest\x12\x0e\n\x06\x61oi_id\x18\x01 \x01(\t\x12\x31\n\x16\x61oi_modification_input\x18\x02 \x01(\x0b\x32\x11.oi.papi.AOIInput\"\x82\x01\n\x18\x41OIVersionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12(\n\x0b\x61oi_version\x18\x03 \x01(\x0b\x32\x13.oi.papi.AOIVersion\"\xa7\x02\n\x15\x41OIVersionListRequest\x12\x10\n\x08geom_wkt\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x13\n\x0bsearch_text\x18\x04 \x01(\t\x12\x32\n\x0emin_created_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12%\n\naoi_fields\x18\x07 \x03(\x0e\x32\x11.oi.papi.AOIField\x12\'\n\npagination\x18\x08 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x0f\n\x07verbose\x18\t \x01(\x08\"\x81\x01\n\x16\x41OIVersionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12)\n\x0c\x61oi_versions\x18\x03 \x03(\x0b\x32\x13.oi.papi.AOIVersion*\xea\x01\n\x08\x41OIField\x12\x15\n\x11UNKNOWN_AOI_FIELD\x10\x00\x12\n\n\x06\x41OI_ID\x10\x01\x12\x0c\n\x08GEOM_WKT\x10\x02\x12\x07\n\x03LAT\x10\x03\x12\x08\n\x04LONG\x10\x04\x12\x08\n\x04NAME\x10\x05\x12\x0c\n\x08\x41REA_KM2\x10\x06\x12\x0c\n\x08\x43\x41TEGORY\x10\x07\x12\x08\n\x04TYPE\x10\x08\x12\n\n\x06SOURCE\x10\t\x12\x0b\n\x07\x43OUNTRY\x10\n\x12\t\n\x05STATE\x10\x0b\x12\x08\n\x04TAGS\x10\x0c\x12\x0e\n\nATTRIBUTES\x10\r\x12\x0c\n\x08TIMEZONE\x10\x0e\x12\x0e\n\nCREATED_ON\x10\x0f\x12\x0e\n\nCREATED_BY\x10\x10\x32\xed\x01\n\rAOIVersionApi\x12M\n\x06\x63reate\x12 .oi.papi.AOIVersionCreateRequest\x1a!.oi.papi.AOIVersionCreateResponse\x12\x44\n\x03get\x12\x1d.oi.papi.AOIVersionGetRequest\x1a\x1e.oi.papi.AOIVersionGetResponse\x12G\n\x04list\x12\x1e.oi.papi.AOIVersionListRequest\x1a\x1f.oi.papi.AOIVersionListResponseP\x00P\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_version_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AOIFIELD']._serialized_start=1001
  _globals['_AOIFIELD']._serialized_end=1235
  _globals['_AOIVERSIONGETREQUEST']._serialized_start=95
  _globals['_AOIVERSIONGETREQUEST']._serialized_end=210
  _globals['_AOIVERSIONGETRESPONSE']._serialized_start=213
  _globals['_AOIVERSIONGETRESPONSE']._serialized_end=341
  _globals['_AOIVERSIONCREATEREQUEST']._serialized_start=343
  _globals['_AOIVERSIONCREATEREQUEST']._serialized_end=435
  _globals['_AOIVERSIONCREATERESPONSE']._serialized_start=438
  _globals['_AOIVERSIONCREATERESPONSE']._serialized_end=568
  _globals['_AOIVERSIONLISTREQUEST']._serialized_start=571
  _globals['_AOIVERSIONLISTREQUEST']._serialized_end=866
  _globals['_AOIVERSIONLISTRESPONSE']._serialized_start=869
  _globals['_AOIVERSIONLISTRESPONSE']._serialized_end=998
  _globals['_AOIVERSIONAPI']._serialized_start=1238
  _globals['_AOIVERSIONAPI']._serialized_end=1475
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"7\n\rLoginResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x11\n\tjwt_token\x18\x02 \x01(\t\"G\n\x19UserChangePasswordRequest\x12\x14\n\x0cold_password\x18\x01 \x01(\t\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"1\n\x1aUserChangePasswordResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"/\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"L\n\x11UserCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x1a\n\x12user_collection_id\x18\x03 \x01(\t\"F\n\x12UserCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1b\n\x04user\x18\x02 \x01(\x0b\x32\r.oi.papi.User\"\x1d\n\x0eUserGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"D\n\x0fUserGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User\" \n\x0fUserListRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"E\n\x10UserListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User2\xd7\x02\n\x07UserApi\x12\x36\n\x05login\x12\x15.oi.papi.LoginRequest\x1a\x16.oi.papi.LoginResponse\x12Z\n\x0f\x63hange_password\x12\".oi.papi.UserChangePasswordRequest\x1a#.oi.papi.UserChangePasswordResponse\x12\x41\n\x06\x63reate\x12\x1a.oi.papi.UserCreateRequest\x1a\x1b.oi.papi.UserCreateResponse\x12\x38\n\x03get\x12\x17.oi.papi.UserGetRequest\x1a\x18.oi.papi.UserGetResponse\x12;\n\x04list\x12\x18.oi.papi.UserListRequest\x1a\x19.oi.papi.UserListResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LOGINREQUEST']._serialized_start=44
  _globals['_LOGINREQUEST']._serialized_end=91
  _globals['_LOGINRESPONSE']._serialized_start=93
  _globals['_LOGINRESPONSE']._serialized_end=148
  _globals['_USERCHANGEPASSWORDREQUEST']._serialized_start=150
  _globals['_USERCHANGEPASSWORDREQUEST']._serialized_end=221
  _globals['_USERCHANGEPASSWORDRESPONSE']._serialized_start=223
  _globals['_USERCHANGEPASSWORDRESPONSE']._serialized_end=272
  _globals['_USER']._serialized_start=274
  _globals['_USER']._serialized_end=321
  _globals['_USERCREATEREQUEST']._serialized_start=323
  _globals['_USERCREATEREQUEST']._serialized_end=399
  _globals['_USERCREATERESPONSE']._serialized_start=401
  _globals['_USERCREATERESPONSE']._serialized_end=471
  _globals['_USERGETREQUEST']._serialized_start=473
  _globals['_USERGETREQUEST']._serialized_end=502
  _globals['_USERGETRESPONSE']._serialized_start=504
  _globals['_USERGETRESPONSE']._serialized_end=572
  _globals['_USERLISTREQUEST']._serialized_start=574
  _globals['_USERLISTREQUEST']._serialized_end=606
  _globals['_USERLISTRESPONSE']._serialized_start=608
  _globals['_USERLISTRESPONSE']._serialized_end=677
  _globals['_USERAPI']._serialized_start=680
  _globals['_USERAPI']._serialized_end=1023
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import analysis_pb2 as analysis__pb2


class AnalysisApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.AnalysisApi/create',
                request_serializer=analysis__pb2.AnalysisCreateRequest.SerializeToString,
                response_deserializer=analysis__pb2.AnalysisCreateResponse.FromString,
                )
        self.get = channel.unary_unary(
                '/oi.papi.AnalysisApi/get',
                request_serializer=analysis__pb2.AnalysisGetRequest.SerializeToString,
                response_deserializer=analysis__pb2.AnalysisGetResponse.FromString,
                )
        self.list = channel.unary_unary(
                '/oi.papi.AnalysisApi/list',
                request_serializer=analysis__pb2.AnalysisListRequest.SerializeToString,
                response_deserializer=analysis__pb2.AnalysisListResponse.FromString,
                )


class AnalysisApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Create a top level Analysis object.
        This object is lightweight and is used to connect all versions of an Analysis together.
        Once an Analysis has been created, an AnalysisVersion must be created using a manifest.
        Next an AnalysisConfig may be created to specify a particular configuration of an AnalysisVersion, which can be used in an AnalysisComputation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Retrieve the metadata of a particular analysis.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        Retrieve the metadata for all Analyses that this user has access to and that match the provided search filters, if any.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AnalysisApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=analysis__pb2.AnalysisCreateRequest.FromString,
                    response_serializer=analysis__pb2.AnalysisCreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=analysis__pb2.AnalysisGetRequest.FromString,
                    response_serializer=analysis__pb2.AnalysisGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=analysis__pb2.AnalysisListRequest.FromString,
                    response_serializer=analysis__pb2.AnalysisListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AnalysisApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AnalysisApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AnalysisApi/create',
            analysis__pb2.AnalysisCreateRequest.SerializeToString,
            analysis__pb2.AnalysisCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AnalysisApi/get',
            analysis__pb2.AnalysisGetRequest.SerializeToString,
            analysis__pb2.AnalysisGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AnalysisApi/list',
            analysis__pb2.AnalysisListRequest.SerializeToString,
            analysis__pb2.AnalysisListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: visualization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13visualization.proto\x12\x15oi.papi.visualization\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe4\x05\n\rVisualization\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0e\x63omputation_id\x18\x02 \x01(\t\x12\x1d\n\x15result_observation_id\x18\x03 \x01(\t\x12\x37\n\x04type\x18\x04 \x01(\x0e\x32).oi.papi.visualization.Visualization.Type\x12\x39\n\x05state\x18\x05 \x01(\x0e\x32*.oi.papi.visualization.Visualization.State\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x14observation_metadata\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x0b\x61\x63\x63\x65ss_info\x18\x07 \x01(\x0b\x32/.oi.papi.visualization.Visualization.AccessInfo\x12.\n\ncreated_on\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aP\n\nAccessInfo\x12\x14\n\x0curl_template\x18\x01 \x01(\t\x12,\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"A\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x0b\n\x07SPATIAL\x10\x02\x12\x0c\n\x08TEMPORAL\x10\x03\"\x7f\n\x05State\x12\x11\n\rUNKNOWN_STATE\x10\x00\x12\x07\n\x03NEW\x10\x01\x12\n\n\x06QUEUED\x10\x02\x12\x0e\n\nVALIDATING\x10\x03\x12\t\n\x05\x45MPTY\x10\x04\x12\x0c\n\x08UPLOADED\x10\x05\x12\n\n\x06\x46\x41ILED\x10\x06\x12\x0c\n\x08\x44\x45LETING\x10\x07\x12\x0b\n\x07\x44\x45LETED\x10\x08\"9\n\x17VisualizationGetRequest\x12\x1e\n\x16result_observation_ids\x18\x01 \x03(\t\"\x88\x01\n\x18VisualizationGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12<\n\x0evisualizations\x18\x02 \x03(\x0b\x32$.oi.papi.visualization.Visualization\x12\x19\n\x11\x62\x61se_url_template\x18\x03 \x01(\t\"\xdd\x01\n\nVisualizer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12I\n\x0fvisualizer_type\x18\x03 \x01(\x0e\x32\x30.oi.papi.visualization.Visualizer.VisualizerType\x12\x11\n\tdata_type\x18\x04 \x01(\t\"W\n\x0eVisualizerType\x12\x1b\n\x17UNKNOWN_VISUALIZER_TYPE\x10\x00\x12\n\n\x06KEPLER\x10\x01\x12\x1c\n\x18OI_VISUALIZATION_SERVICE\x10\x02\"~\n\x10VisualizerConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\nvisualizer\x18\x03 \x01(\x0b\x32!.oi.papi.visualization.Visualizer\"y\n\x14VisualizerConfigAlgo\x12\x1c\n\x14\x61lgorithm_version_id\x18\x01 \x01(\t\x12\x43\n\x12visualizer_configs\x18\x02 \x03(\x0b\x32\'.oi.papi.visualization.VisualizerConfig\"f\n(VisualizerConfigAlgoVersionCreateRequest\x12\x1c\n\x14visualizer_config_id\x18\x01 \x01(\t\x12\x1c\n\x14\x61lgorithm_version_id\x18\x02 \x01(\t\"@\n)VisualizerConfigAlgoVersionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"?\n\x1eVisualizerConfigAlgoGetRequest\x12\x1d\n\x15\x61lgorithm_version_ids\x18\x01 \x03(\t\"\x84\x01\n\x1fVisualizerConfigAlgoGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12L\n\x17visualizer_config_algos\x18\x02 \x03(\x0b\x32+.oi.papi.visualization.VisualizerConfigAlgo\"d\n\'VisualizerConfigAlgoConfigCreateRequest\x12\x1c\n\x14visualizer_config_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61lgorithm_config_id\x18\x02 \x01(\t\"?\n(VisualizerConfigAlgoConfigCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xbe\x04\n\x10VisualizationApi\x12\x66\n\x03get\x12..oi.papi.visualization.VisualizationGetRequest\x1a/.oi.papi.visualization.VisualizationGetResponse\x12\x9f\x01\n\x1a\x63reate_config_algo_version\x12?.oi.papi.visualization.VisualizerConfigAlgoVersionCreateRequest\x1a@.oi.papi.visualization.VisualizerConfigAlgoVersionCreateResponse\x12\x9c\x01\n\x19\x63reate_config_algo_config\x12>.oi.papi.visualization.VisualizerConfigAlgoConfigCreateRequest\x1a?.oi.papi.visualization.VisualizerConfigAlgoConfigCreateResponse\x12\x80\x01\n\x0fget_config_algo\x12\x35.oi.papi.visualization.VisualizerConfigAlgoGetRequest\x1a\x36.oi.papi.visualization.VisualizerConfigAlgoGetResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'visualization_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_VISUALIZATION']._serialized_start=110
  _globals['_VISUALIZATION']._serialized_end=850
  _globals['_VISUALIZATION_ACCESSINFO']._serialized_start=574
  _globals['_VISUALIZATION_ACCESSINFO']._serialized_end=654
  _globals['_VISUALIZATION_TYPE']._serialized_start=656
  _globals['_VISUALIZATION_TYPE']._serialized_end=721
  _globals['_VISUALIZATION_STATE']._serialized_start=723
  _globals['_VISUALIZATION_STATE']._serialized_end=850
  _globals['_VISUALIZATIONGETREQUEST']._serialized_start=852
  _globals['_VISUALIZATIONGETREQUEST']._serialized_end=909
  _globals['_VISUALIZATIONGETRESPONSE']._serialized_start=912
  _globals['_VISUALIZATIONGETRESPONSE']._serialized_end=1048
  _globals['_VISUALIZER']._serialized_start=1051
  _globals['_VISUALIZER']._serialized_end=1272
  _globals['_VISUALIZER_VISUALIZERTYPE']._serialized_start=1185
  _globals['_VISUALIZER_VISUALIZERTYPE']._serialized_end=1272
  _globals['_VISUALIZERCONFIG']._serialized_start=1274
  _globals['_VISUALIZERCONFIG']._serialized_end=1400
  _globals['_VISUALIZERCONFIGALGO']._serialized_start=1402
  _globals['_VISUALIZERCONFIGALGO']._serialized_end=1523
  _globals['_VISUALIZERCONFIGALGOVERSIONCREATEREQUEST']._serialized_start=1525
  _globals['_VISUALIZERCONFIGALGOVERSIONCREATEREQUEST']._serialized_end=1627
  _globals['_VISUALIZERCONFIGALGOVERSIONCREATERESPONSE']._serialized_start=1629
  _globals['_VISUALIZERCONFIGALGOVERSIONCREATERESPONSE']._serialized_end=1693
  _globals['_VISUALIZERCONFIGALGOGETREQUEST']._serialized_start=1695
  _globals['_VISUALIZERCONFIGALGOGETREQUEST']._serialized_end=1758
  _globals['_VISUALIZERCONFIGALGOGETRESPONSE']._serialized_start=1761
  _globals['_VISUALIZERCONFIGALGOGETRESPONSE']._serialized_end=1893
  _globals['_VISUALIZERCONFIGALGOCONFIGCREATEREQUEST']._serialized_start=1895
  _globals['_VISUALIZERCONFIGALGOCONFIGCREATEREQUEST']._serialized_end=1995
  _globals['_VISUALIZERCONFIGALGOCONFIGCREATERESPONSE']._serialized_start=1997
  _globals['_VISUALIZERCONFIGALGOCONFIGCREATERESPONSE']._serialized_end=2060
  _globals['_VISUALIZATIONAPI']._serialized_start=2063
  _globals['_VISUALIZATIONAPI']._serialized_end=2637
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import user_collection_pb2 as user__collection__pb2


class UserCollectionApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.UserCollectionApi/create',
                request_serializer=user__collection__pb2.UserCollectionCreateRequest.SerializeToString,
                response_deserializer=user__collection__pb2.UserCollectionCreateResponse.FromString,
                )
        self.get = channel.unary_unary(
                '/oi.papi.UserCollectionApi/get',
                request_serializer=user__collection__pb2.UserCollectionGetRequest.SerializeToString,
                response_deserializer=user__collection__pb2.UserCollectionGetResponse.FromString,
                )
        self.list = channel.unary_unary(
                '/oi.papi.UserCollectionApi/list',
                request_serializer=user__collection__pb2.UserCollectionListRequest.SerializeToString,
                response_deserializer=user__collection__pb2.UserCollectionListResponse.FromString,
                )


class UserCollectionApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Create a new UserCollection to house a collection of users. This can only be done by an admin.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get the details of a UserCollection. This can only done for the UserCollection that a User is a part of.
        If include_users is set to true, this endpoint also returns the list of Users in the UserCollection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        List user collections a user is a member of
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserCollectionApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=user__collection__pb2.UserCollectionCreateRequest.FromString,
                    response_serializer=user__collection__pb2.UserCollectionCreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=user__collection__pb2.UserCollectionGetRequest.FromString,
                    response_serializer=user__collection__pb2.UserCollectionGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=user__collection__pb2.UserCollectionListRequest.FromString,
                    response_serializer=user__collection__pb2.UserCollectionListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.UserCollectionApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserCollectionApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.UserCollectionApi/create',
            user__collection__pb2.UserCollectionCreateRequest.SerializeToString,
            user__collection__pb2.UserCollectionCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.UserCollectionApi/get',
            user__collection__pb2.UserCollectionGetRequest.SerializeToString,
            user__collection__pb2.UserCollectionGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.UserCollectionApi/list',
            user__collection__pb2.UserCollectionListRequest.SerializeToString,
            user__collection__pb2.UserCollectionListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aoi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\taoi.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"\x8c\x01\n\x0e\x41OITransaction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12.\n\ncreated_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"7\n\rAOIIdentifier\x12\x0e\n\x06\x61oi_id\x18\x01 \x01(\t\x12\x16\n\x0e\x61oi_version_id\x18\x02 \x01(\r\"\xa5\x02\n\tAOIObject\x12.\n\x0e\x61oi_identifier\x18\x01 \x01(\x0b\x32\x16.oi.papi.AOIIdentifier\x12\x10\n\x08geom_wkt\x18\x02 \x01(\t\x12\x0b\n\x03lat\x18\x03 \x01(\x02\x12\x0c\n\x04long\x18\x04 \x01(\x02\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08\x61rea_km2\x18\x06 \x01(\x01\x12\x10\n\x08\x63\x61tegory\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\x12\x0e\n\x06source\x18\t \x01(\t\x12\x0f\n\x07\x63ountry\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\t\x12\x0c\n\x04tags\x18\x0c \x03(\t\x12+\n\nattributes\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08timezone\x18\x0e \x01(\t\"\xdf\x02\n\nAOIVersion\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06\x61oi_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63reator\x18\x04 \x01(\t\x12\x10\n\x08\x61oi_name\x18\x05 \x01(\t\x12\x10\n\x08geom_wkt\x18\x06 \x01(\t\x12\x0b\n\x03lat\x18\x07 \x01(\x02\x12\x0c\n\x04long\x18\x08 \x01(\x02\x12\x10\n\x08\x61rea_km2\x18\t \x01(\x01\x12\x10\n\x08\x63\x61tegory\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\x12\x0e\n\x06source\x18\x0c \x01(\t\x12\x0f\n\x07\x63ountry\x18\r \x01(\t\x12\r\n\x05state\x18\x0e \x01(\t\x12\x0c\n\x04tags\x18\x0f \x03(\t\x12+\n\nattributes\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08timezone\x18\x11 \x01(\t\"\x95\x01\n\x08\x41OIInput\x12\x0e\n\x06\x61oi_id\x18\x01 \x01(\t\x12\x10\n\x08geom_wkt\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12+\n\nattributes\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\"T\n\x10\x41OICreateRequest\x12%\n\naoi_inputs\x18\x01 \x03(\x0b\x32\x11.oi.papi.AOIInput\x12\x19\n\x11\x61oi_collection_id\x18\x02 \x01(\t\"\x94\x01\n\x11\x41OICreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12/\n\x0f\x61oi_identifiers\x18\x03 \x03(\x0b\x32\x16.oi.papi.AOIIdentifier\x12\x10\n\x08\x61rea_km2\x18\x04 \x03(\x01\"<\n\x10\x41OIUploadRequest\x12\x19\n\x11\x61oi_collection_id\x18\x01 \x01(\t\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\"Z\n\x11\x41OIUploadResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x30\n\x0f\x61oi_transaction\x18\x02 \x01(\x0b\x32\x17.oi.papi.AOITransaction\"V\n\rAOIGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x0f\n\x07verbose\x18\x02 \x01(\x08\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"y\n\x0e\x41OIGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12)\n\x0c\x61oi_versions\x18\x03 \x03(\x0b\x32\x13.oi.papi.AOIVersion\"U\n\x10\x41OIUpdateRequest\x12\x0e\n\x06\x61oi_id\x18\x01 \x01(\t\x12\x31\n\x16\x61oi_modification_input\x18\x02 \x01(\x0b\x32\x11.oi.papi.AOIInput\"(\n\x11\x41OIUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\x85\x02\n\x06\x41OIApi\x12?\n\x06\x63reate\x12\x19.oi.papi.AOICreateRequest\x1a\x1a.oi.papi.AOICreateResponse\x12\x36\n\x03get\x12\x16.oi.papi.AOIGetRequest\x1a\x17.oi.papi.AOIGetResponse\x12\x41\n\x06upload\x12\x19.oi.papi.AOIUploadRequest\x1a\x1a.oi.papi.AOIUploadResponse(\x01\x12?\n\x06update\x12\x19.oi.papi.AOIUpdateRequest\x1a\x1a.oi.papi.AOIUpdateResponseP\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AOITRANSACTION']._serialized_start=107
  _globals['_AOITRANSACTION']._serialized_end=247
  _globals['_AOIIDENTIFIER']._serialized_start=249
  _globals['_AOIIDENTIFIER']._serialized_end=304
  _globals['_AOIOBJECT']._serialized_start=307
  _globals['_AOIOBJECT']._serialized_end=600
  _globals['_AOIVERSION']._serialized_start=603
  _globals['_AOIVERSION']._serialized_end=954
  _globals['_AOIINPUT']._serialized_start=957
  _globals['_AOIINPUT']._serialized_end=1106
  _globals['_AOICREATEREQUEST']._serialized_start=1108
  _globals['_AOICREATEREQUEST']._serialized_end=1192
  _globals['_AOICREATERESPONSE']._serialized_start=1195
  _globals['_AOICREATERESPONSE']._serialized_end=1343
  _globals['_AOIUPLOADREQUEST']._serialized_start=1345
  _globals['_AOIUPLOADREQUEST']._serialized_end=1405
  _globals['_AOIUPLOADRESPONSE']._serialized_start=1407
  _globals['_AOIUPLOADRESPONSE']._serialized_end=1497
  _globals['_AOIGETREQUEST']._serialized_start=1499
  _globals['_AOIGETREQUEST']._serialized_end=1585
  _globals['_AOIGETRESPONSE']._serialized_start=1587
  _globals['_AOIGETRESPONSE']._serialized_end=1708
  _globals['_AOIUPDATEREQUEST']._serialized_start=1710
  _globals['_AOIUPDATEREQUEST']._serialized_end=1795
  _globals['_AOIUPDATERESPONSE']._serialized_start=1797
  _globals['_AOIUPDATERESPONSE']._serialized_end=1837
  _globals['_AOIAPI']._serialized_start=1840
  _globals['_AOIAPI']._serialized_end=2101
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: result.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import toi_pb2 as toi__pb2
try:
  common__models__pb2 = toi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = toi__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.toi_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cresult.proto\x12\x07oi.papi\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\ttoi.proto\"\xae\x05\n\x06Result\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12source_aoi_version\x18\x03 \x01(\r\x12\x18\n\x10\x64\x65st_aoi_version\x18\x04 \x01(\r\x12\x19\n\x11\x61lgo_config_class\x18\x05 \x01(\t\x12\x1c\n\x14\x61lgo_config_subclass\x18\x06 \x01(\t\x12\x31\n\x0cobservations\x18\x07 \x03(\x0b\x32\x1b.oi.papi.Result.Observation\x12\x11\n\tdata_type\x18\x08 \x01(\t\x1a\xb2\x03\n\x0bObservation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61ta_view_id\x18\x02 \x01(\t\x12.\n\ncreated_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08start_ts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x05value\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x06status\x18\x06 \x01(\x0e\x32\".oi.papi.Result.Observation.Status\x12=\n\x0cmeasurements\x18\x07 \x03(\x0b\x32\'.oi.papi.Result.Observation.Measurement\x1aO\n\x0bMeasurement\x12\n\n\x02id\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0c\n\x04geom\x18\x03 \x01(\t\"7\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0c\n\x08\x43OMPLETE\x10\x01\x12\x0b\n\x07PARTIAL\x10\x02\"\xb9\x03\n\x10ResultGetRequest\x12 \n\x18\x61lgorithm_computation_id\x18\x01 \x01(\t\x12\x1a\n\x12source_aoi_version\x18\x02 \x01(\r\x12\x18\n\x10\x64\x65st_aoi_version\x18\x03 \x01(\r\x12\x19\n\x11\x61lgo_config_class\x18\x04 \x01(\t\x12\x1c\n\x14\x61lgo_config_subclass\x18\x05 \x01(\t\x12.\n\ncreated_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14observation_start_ts\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08geom_wkt\x18\x08 \x01(\t\x12>\n\x12observation_status\x18\t \x01(\x0e\x32\".oi.papi.Result.Observation.Status\x12\x1c\n\x14include_measurements\x18\n \x01(\x08\x12\x11\n\tdata_type\x18\x0b \x01(\t\x12\'\n\npagination\x18\x0c \x01(\x0b\x32\x13.oi.papi.Pagination\"s\n\x11ResultGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12 \n\x07results\x18\x03 \x03(\x0b\x32\x0f.oi.papi.Result\"\xeb\x02\n\x13ResultExportRequest\x12 \n\x18\x61lgorithm_computation_id\x18\x01 \x01(\t\x12<\n\x0b\x65xport_type\x18\x02 \x01(\x0e\x32\'.oi.papi.ResultExportRequest.ExportType\x12\x38\n\tfile_type\x18\x03 \x01(\x0e\x32%.oi.papi.ResultExportRequest.FileType\x12\x1a\n\x12source_aoi_version\x18\x04 \x01(\r\"U\n\nExportType\x12\x17\n\x13UNKNOWN_EXPORT_TYPE\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x0c\n\x08\x44\x45TAILED\x10\x02\x12\x12\n\x0eSINGLE_OBJECTS\x10\x03\"G\n\x08\x46ileType\x12\x15\n\x11UNKNOWN_FILE_TYPE\x10\x00\x12\x07\n\x03\x43SV\x10\x01\x12\x0b\n\x07GEOJSON\x10\x02\x12\x0e\n\nGEOPACKAGE\x10\x03\"c\n\x14ResultExportResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t\x12 \n\x18\x61lgorithm_computation_id\x18\x03 \x01(\t2\xc3\x01\n\tResultApi\x12T\n\x03get\x12\x19.oi.papi.ResultGetRequest\x1a\x1a.oi.papi.ResultGetResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/result/get:\x01*\x12`\n\x06\x65xport\x12\x1c.oi.papi.ResultExportRequest\x1a\x1d.oi.papi.ResultExportResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/result/export:\x01*P\x03P\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'result_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESULTAPI.methods_by_name['get']._options = None
  _RESULTAPI.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\020\"\013/result/get:\001*'
  _RESULTAPI.methods_by_name['export']._options = None
  _RESULTAPI.methods_by_name['export']._serialized_options = b'\202\323\344\223\002\023\"\016/result/export:\001*'
  _globals['_RESULT']._serialized_start=151
  _globals['_RESULT']._serialized_end=837
  _globals['_RESULT_OBSERVATION']._serialized_start=403
  _globals['_RESULT_OBSERVATION']._serialized_end=837
  _globals['_RESULT_OBSERVATION_MEASUREMENT']._serialized_start=701
  _globals['_RESULT_OBSERVATION_MEASUREMENT']._serialized_end=780
  _globals['_RESULT_OBSERVATION_STATUS']._serialized_start=782
  _globals['_RESULT_OBSERVATION_STATUS']._serialized_end=837
  _globals['_RESULTGETREQUEST']._serialized_start=840
  _globals['_RESULTGETREQUEST']._serialized_end=1281
  _globals['_RESULTGETRESPONSE']._serialized_start=1283
  _globals['_RESULTGETRESPONSE']._serialized_end=1398
  _globals['_RESULTEXPORTREQUEST']._serialized_start=1401
  _globals['_RESULTEXPORTREQUEST']._serialized_end=1764
  _globals['_RESULTEXPORTREQUEST_EXPORTTYPE']._serialized_start=1606
  _globals['_RESULTEXPORTREQUEST_EXPORTTYPE']._serialized_end=1691
  _globals['_RESULTEXPORTREQUEST_FILETYPE']._serialized_start=1693
  _globals['_RESULTEXPORTREQUEST_FILETYPE']._serialized_end=1764
  _globals['_RESULTEXPORTRESPONSE']._serialized_start=1766
  _globals['_RESULTEXPORTRESPONSE']._serialized_end=1865
  _globals['_RESULTAPI']._serialized_start=1868
  _globals['_RESULTAPI']._serialized_end=2063
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12notification.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\"j\n\x0cSubscription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08topic_id\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\t\x12(\n\x07\x66ilters\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"I\n\x19SubscriptionCreateRequest\x12,\n\rsubscriptions\x18\x01 \x03(\x0b\x32\x15.oi.papi.Subscription\"K\n\x1aSubscriptionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x18\n\x10subscription_ids\x18\x02 \x03(\t\"(\n\x05Topic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\'\n\x10TopicListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"H\n\x11TopicListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1e\n\x06topics\x18\x02 \x03(\x0b\x32\x0e.oi.papi.Topic\"#\n\x07\x43hannel\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\")\n\x12\x43hannelListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"N\n\x13\x43hannelListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\"\n\x08\x63hannels\x18\x02 \x03(\x0b\x32\x10.oi.papi.Channel\"(\n\x19SubscriptionDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"1\n\x1aSubscriptionDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"B\n\x17SubscriptionListRequest\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x86\x01\n\x18SubscriptionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12,\n\rsubscriptions\x18\x02 \x03(\x0b\x32\x15.oi.papi.Subscription\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"t\n\x17NotificationSendRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12(\n\x07\x66ilters\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"/\n\x18NotificationSendResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\x95\x04\n\x0fNotificationApi\x12^\n\x13\x63reate_subscription\x12\".oi.papi.SubscriptionCreateRequest\x1a#.oi.papi.SubscriptionCreateResponse\x12\x43\n\nlist_topic\x12\x19.oi.papi.TopicListRequest\x1a\x1a.oi.papi.TopicListResponse\x12I\n\x0clist_channel\x12\x1b.oi.papi.ChannelListRequest\x1a\x1c.oi.papi.ChannelListResponse\x12^\n\x13\x64\x65lete_subscription\x12\".oi.papi.SubscriptionDeleteRequest\x1a#.oi.papi.SubscriptionDeleteResponse\x12X\n\x11list_subscription\x12 .oi.papi.SubscriptionListRequest\x1a!.oi.papi.SubscriptionListResponse\x12X\n\x11send_notification\x12 .oi.papi.NotificationSendRequest\x1a!.oi.papi.NotificationSendResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SUBSCRIPTION']._serialized_start=82
  _globals['_SUBSCRIPTION']._serialized_end=188
  _globals['_SUBSCRIPTIONCREATEREQUEST']._serialized_start=190
  _globals['_SUBSCRIPTIONCREATEREQUEST']._serialized_end=263
  _globals['_SUBSCRIPTIONCREATERESPONSE']._serialized_start=265
  _globals['_SUBSCRIPTIONCREATERESPONSE']._serialized_end=340
  _globals['_TOPIC']._serialized_start=342
  _globals['_TOPIC']._serialized_end=382
  _globals['_TOPICLISTREQUEST']._serialized_start=384
  _globals['_TOPICLISTREQUEST']._serialized_end=423
  _globals['_TOPICLISTRESPONSE']._serialized_start=425
  _globals['_TOPICLISTRESPONSE']._serialized_end=497
  _globals['_CHANNEL']._serialized_start=499
  _globals['_CHANNEL']._serialized_end=534
  _globals['_CHANNELLISTREQUEST']._serialized_start=536
  _globals['_CHANNELLISTREQUEST']._serialized_end=577
  _globals['_CHANNELLISTRESPONSE']._serialized_start=579
  _globals['_CHANNELLISTRESPONSE']._serialized_end=657
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_start=659
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_end=699
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_start=701
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_end=750
  _globals['_SUBSCRIPTIONLISTREQUEST']._serialized_start=752
  _globals['_SUBSCRIPTIONLISTREQUEST']._serialized_end=818
  _globals['_SUBSCRIPTIONLISTRESPONSE']._serialized_start=821
  _globals['_SUBSCRIPTIONLISTRESPONSE']._serialized_end=955
  _globals['_NOTIFICATIONSENDREQUEST']._serialized_start=957
  _globals['_NOTIFICATIONSENDREQUEST']._serialized_end=1073
  _globals['_NOTIFICATIONSENDRESPONSE']._serialized_start=1075
  _globals['_NOTIFICATIONSENDRESPONSE']._serialized_end=1122
  _globals['_NOTIFICATIONAPI']._serialized_start=1125
  _globals['_NOTIFICATIONAPI']._serialized_end=1658
# @@protoc_insertion_point(module_scope)
